@@ -5,6 +5,7 @@ from sqlalchemy import (
     DateTime,
     Boolean,
     ForeignKey,
+    Text,
 )
 from datetime import datetime
 
@@ -31,6 +32,8 @@ class CompanyOUSModel(Base):
         ForeignKey('companies_sec.id'),
         nullable=True,
     )
+    relevant_links = Column(Text, nullable=True)
+    notes = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
