@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Float,
+    Boolean,
 )
 
 from ...database import Base
@@ -26,6 +27,8 @@ class CrawlerLogModel(Base):
         nullable=True,
     )
     crawl_time = Column(Float, nullable=False)
+    base_crawl_time = Column(Float, nullable=True)
+    base_crawl_completed = Column(Boolean, nullable=True)
     crawl_date = Column(DateTime, nullable=False)
     updated_at = Column(
         DateTime,
