@@ -2,6 +2,7 @@ from sqlalchemy import (
     Column,
     Integer,
     String,
+    Binary,
 )
 
 from ...database import Base
@@ -12,7 +13,7 @@ class DOILinkModel(Base):
 
     id = Column(Integer, primary_key=True)
     link = Column(
-        String(191),
+        Binary(16),
         nullable=False,
         index=True,
     )
