@@ -32,11 +32,6 @@ class DocTextModel(Base):
         ForeignKey('company_filings.id'),
         nullable=True,
     )
-    scientific_link_id = Column(
-        Integer,
-        ForeignKey('scientific_links.id'),
-        nullable=True,
-    )
     pubmed_id = Column(
         Integer,
         ForeignKey('pubmed.id'),
