@@ -12,5 +12,6 @@ class DrugIndicationUMLSResourceSchema(Schema):
     set_id = fields.String(validate=not_blank, required=True)
     cui = fields.String(required=True)
     preferred_name = fields.String(allow_none=True)
-    score = fields.Integer()
+    score = fields.Integer(allow_none=True)
+    final_mapping = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
