@@ -17,7 +17,11 @@ class LatestPipelineProductModel(Base):
 
     id = Column(Integer, primary_key=True)
     product_name = Column(String(191), nullable=False, index=True)
-    norm_cui = Column(String(50), nullable=False)
+    intervention_id = Column(
+        Integer,
+        ForeignKey('interventions.id'),
+        nullable=False,
+    )
     news_id = Column(
         Integer,
         ForeignKey('newswires.id'),
