@@ -6,6 +6,8 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Text,
+    String,
+    Boolean,
 )
 
 from ...database import Base
@@ -21,6 +23,8 @@ class LicensingCollabSentenceModel(Base):
         nullable=False,
     )
     text = Column(Text, nullable=False, index=True)
+    type = Column(String(50), nullable=True)
+    llm_output = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
