@@ -6,6 +6,7 @@ from sqlalchemy import (
     String,
     DateTime,
     Boolean,
+    ForeignKey,
 )
 
 from ...database import Base
@@ -19,6 +20,11 @@ class MeetingModel(Base):
     start_date = Column(DateTime, nullable=False)
     end_date = Column(DateTime, nullable=False)
     from_website = Column(Boolean, nullable=True)
+    meeting_bucket_id = Column(
+        Integer,
+        ForeignKey('meeting_bucket.id'),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
