@@ -11,4 +11,6 @@ class MergerSentenceResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     merger_id = fields.Integer(required=True)
     text = fields.String(required=True, validate=not_blank)
+    type = fields.String(allow_none=True)
+    llm_output = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
