@@ -24,6 +24,8 @@ class NCTStudyModel(Base):
     why_stopped = Column(Text, nullable=True)
     primary_completion_date = Column(DateTime, nullable=True)
     primary_completion_date_type = Column(String(128), nullable=True)
+    study_completion_date = Column(DateTime, nullable=True)
+    study_completion_date_type = Column(String(128), nullable=True)
     study_first_posted_date = Column(DateTime, nullable=True)
     study_status = Column(String(128))
     study_type = Column(String(50))
