@@ -21,6 +21,8 @@ class NCTStudyResourceSchema(Schema):
     why_stopped = fields.String(allow_none=True)
     primary_completion_date = fields.DateTime(allow_none=True)
     primary_completion_date_type = fields.String(allow_none=True)
+    study_completion_date = fields.DateTime(allow_none=True)
+    study_completion_date_type = fields.String(allow_none=True)
     study_first_posted_date = fields.DateTime(allow_none=True)
     study_status = fields.String(allow_none=True)
     study_type = fields.String(allow_none=True)
@@ -35,7 +37,7 @@ class NCTStudyResourceSchema(Schema):
 
     @pre_load
     def convert_string_to_datetime(self, in_data, **kwargs):
-        date_fields = ['study_start_date', 'last_update_submitted_qc_date', 'study_first_posted_date', 'primary_completion_date']
+        date_fields = ['study_start_date', 'last_update_submitted_qc_date', 'study_first_posted_date', 'primary_completion_date', 'study_completion_date']
 
         in_data = pre_load_date_fields(
             in_data,
