@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     ForeignKey,
+    Float,
 )
 from datetime import datetime
 
@@ -20,6 +21,7 @@ class NewsTagModel(Base):
         nullable=False,
     )
     tag = Column(String(50), nullable=False, index=True)
+    score = Column(Float, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
