@@ -1,3 +1,4 @@
+from datetime import datetime
 from sqlalchemy import (
     Column,
     Integer,
@@ -32,4 +33,10 @@ class OrangeBookProductModel(Base):
     trade_name = Column(String(256), index=True)
     type = Column(String(256))
     drug_set_id = Column(String(128), nullable=True)
-    updated_at = Column(DateTime)
+    updated_at = Column(
+        DateTime,
+        nullable=False,
+        default=datetime.utcnow,
+        onupdate=datetime.utcnow,
+    )
+
