@@ -47,7 +47,7 @@ class PTAB2ProceedingResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = [
             'accorded_filing_date',
             'decision_date',
