@@ -51,6 +51,8 @@ class PatentModel(Base):
     assignee = Column(Text)
     patent_pdf_url = Column(String(500))
     espace_url = Column(String(500))
+    docdb_family_id = Column(Integer)
+    inpadoc_family_id = Column(Integer)
 
     updated_at = Column(
         DateTime,
