@@ -13,5 +13,5 @@ class PatentApplicationTargetResourceSchema(Schema):
     target_id = fields.Integer(required=True)
     score = fields.Float(required=True)
     preferred = fields.Boolean(allow_none=True)
-    filed_date = fields.DateTime(allow_none=True)
+    published_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime()
