@@ -17,14 +17,20 @@ class PatentIFWModel(Base):
     patent_id = Column(
         Integer,
         ForeignKey('patents.id'),
+        nullable=True,
+    )
+    patent_application_id = Column(
+        Integer,
+        ForeignKey('patent_applications.id'),
+        nullable=False,
     )
     appl_id = Column(String(128), nullable=False)
     document_identifier = Column(String(50), nullable=False)
-    document_code = Column(String(50))
-    document_description = Column(String(256))
-    direction_category = Column(String(50))
-    official_date = Column(DateTime)
-    total_pages = Column(Integer)
+    document_code = Column(String(50), nullable=True)
+    document_description = Column(String(256), nullable=True)
+    direction_category = Column(String(50), nullable=True)
+    official_date = Column(DateTime, nullable=True)
+    total_pages = Column(Integer, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
