@@ -11,9 +11,11 @@ class PubmedResourceSchema(Schema):
     not_blank = validate.Length(min=1, error='Field cannot be blank')
 
     id = fields.Integer(dump_only=True)
-    pubmed_id = fields.Integer(required=True)
+    pubmed_id = fields.Integer(allow_none=True)
     doi = fields.String(allow_none=True)
+    type = fields.String(allow_none=True)
     publication_type = fields.String(allow_none=True)
+    date = fields.DateTime(allow_none=True)
     date_created = fields.DateTime(allow_none=True)
     date_completed = fields.DateTime(allow_none=True)
     date_revised = fields.DateTime(allow_none=True)
@@ -21,6 +23,12 @@ class PubmedResourceSchema(Schema):
     journal_volume = fields.String(allow_none=True)
     journal_issue = fields.String(allow_none=True)
     journal_title = fields.String(allow_none=True)
+    orig_file_url = fields.String(allow_none=True)
+    best_oa_location = fields.String(allow_none=True)
+    outbound_ref_count = fields.Integer(allow_none=True)
+    inbound_ref_count = fields.Integer(allow_none=True)
+    method = fields.String(allow_none=True)
+    verification = fields.String(allow_none=True)
     journal_title_iso_abbrev = fields.String(allow_none=True)
     title = fields.String(required=True)
     abstract = fields.String(allow_none=True)
@@ -33,7 +41,7 @@ class PubmedResourceSchema(Schema):
 
     @pre_load
     def convert_string_to_datetime(self, in_data, **kwargs):
-        date_fields = ['date_created', 'date_completed', 'date_revised']
+        date_fields = ['date', 'date_created', 'date_completed', 'date_revised']
 
         in_data = pre_load_date_fields(
             in_data,
