@@ -22,6 +22,9 @@ class UserSavedSearchModel(Base):
     is_deleted = Column(Boolean, nullable=True)
     created_at = Column(DateTime, nullable=False)
     last_processed = Column(DateTime, nullable=True)
+    instant_notification = Column(Boolean, nullable=True)
+    daily_digest = Column(Boolean, nullable=True)
+    weekly_digest = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
